#
# Conditional build:
%bcond_without	alsa		# ALSA backend
%bcond_without	jack		# JACK backend
%bcond_with	pipewire	# PipeWire backend
%bcond_without	portaudio	# PortAudio backend
%bcond_without	pulseaudio	# PulseAudio backend
%bcond_without	rtkit		# RTKit support
%bcond_with	sdl		# SDL2 backend
%bcond_with	sse2		# force use of SSE2 instructions (x86)
%bcond_without	gui		# alsoft-config GUI

%ifarch pentium4 x32 %{x8664}
%define	with_sse2	1
%endif
Summary:	Open Audio Library
Summary(pl.UTF-8):	Otwarta Biblioteka Dźwięku
Name:		OpenAL
Version:	1.23.1
Release:	1%{?tld}
License:	LGPL v2+
Group:		Libraries
Source0:	https://openal-soft.org/openal-releases/openal-soft-%{version}.tar.bz2
# Source0-md5:	58a73698288d2787451b61f8f4431513
Patch0:		%{name}-nosse.patch
URL:		http://www.openal.org/
%{?with_sdl:BuildRequires:	SDL2-devel >= 2}
%{?with_alsa:BuildRequires:	alsa-lib-devel}
BuildRequires:	cmake >= 3.0.2
%{?with_rtkit:BuildRequires:	dbus-devel}
%{?with_jack:BuildRequires:	jack-audio-connection-kit-devel}
BuildRequires:	libmysofa-devel
BuildRequires:	libstdc++-devel >= 6:5
%{?with_pipewire:BuildRequires:	pipewire-devel >= 0.3.23}
BuildRequires:	pkgconfig
%{?with_portaudio:BuildRequires:	portaudio-devel}
%{?with_pulseaudio:BuildRequires:	pulseaudio-devel}
BuildRequires:	rpmbuild(macros) >= 1.742
%if %{with gui}
BuildRequires:	Qt5Core-devel >= 5
BuildRequires:	Qt5Gui-devel >= 5
BuildRequires:	Qt5Widgets-devel >= 5
BuildRequires:	qt5-build >= 5
%endif
%{?with_sse2:Requires:	cpuinfo(sse2)}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
OpenAL, the Open Audio Library, is a joint effort to create an open,
vendor-neutral, cross-platform API for interactive, primarily
spatialized audio. OpenAL's primary audience are application
developers and desktop users that rely on portable standards like
OpenGL, for games and other multimedia applications. OpenAL is already
supported by a number of hardware vendors and developers.

%description -l pl.UTF-8
OpenAL, otwarta biblioteka dźwięku, to połączony wysiłek w celu
stworzenia otwartego, niezależnego od producentów, międzyplatformowego
interfejsu projektowania aplikacji w części obsługi dźwięku.
Biblioteka adresowana jest do twórców aplikacji i użytkowników,
którzy wybierają przenośne standardy, jak OpenGL, w grach i
aplikacjach multimedialnych. OpenAL posiada już wsparcie wielu
dostarczycieli sprzętu i programistów.

%package devel
Summary:	Headers for OpenAL
Summary(pl.UTF-8):	Pliki nagłówkowe do OpenAL
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
Header files for OpenAL-based programs.

%description devel -l pl.UTF-8
Pliki nagłówkowe potrzebne przy budowaniu programów opartych na
OpenAL.

%package gui
Summary:	OpenAL configuration GUI
Summary(pl.UTF-8):	Graficzny interfejs do konfiguracji biblioteki OpenAL
Group:		X11/Applications/Sound
Requires:	%{name} = %{version}-%{release}
Requires:	Qt5Core >= 5
Requires:	Qt5Gui >= 5
Requires:	Qt5Widgets >= 5

%description gui
OpenAL configuration GUI.

%description gui -l pl.UTF-8
Graficzny interfejs do konfiguracji biblioteki OpenAL.

%prep
%setup -q -n openal-soft-%{version}
%patch0 -p1

%build
cd build
%cmake .. \
	%{!?with_alsa:-DALSOFT_BACKEND_ALSA=OFF} \
	%{!?with_jack:-DALSOFT_BACKEND_JACK=OFF} \
	%{cmake_on_off pipewire ALSOFT_BACKEND_PIPEWIRE} \
	%{!?with_portaudio:-DALSOFT_BACKEND_PORTAUDIO=OFF} \
	%{!?with_pulseaudio:-DALSOFT_BACKEND_PULSEAUDIO=OFF} \
	%{cmake_on_off rtkit ALSOFT_RTKIT} \
	%{?with_sdl:-DALSOFT_BACKEND_SDL2=ON} \
	%{!?with_sse2:-DALSOFT_ENABLE_SSE2_CODEGEN=OFF} \
	-DALSOFT_EXAMPLES=OFF \
	%{!?with_gui:-DALSOFT_NO_CONFIG_UTIL=ON} \

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT%{_sysconfdir}/openal

%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

install -p alsoftrc.sample $RPM_BUILD_ROOT%{_sysconfdir}/openal/alsoft.conf

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/openal
%attr(755,root,root) %{_bindir}/makemhr
%attr(755,root,root) %{_bindir}/openal-info
%attr(755,root,root) %{_libdir}/libopenal.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libopenal.so.1
%{_datadir}/openal

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libopenal.so
%{_includedir}/AL
%{_pkgconfigdir}/openal.pc
%{_libdir}/cmake/OpenAL

%if %{with gui}
%files gui
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/alsoft-config
%endif
%changelog
* Sun Dec 10 2023 TLD Linux <feedback@tld-linux.org>
- For complete changelog see: http://git.tld-linux.org/?p=packages/OpenAL.git;a=log;h=67ac0982e9c6ad81c9365ea8913855d2ea3d43a7

* Wed Apr 12 2023 Jan Palus <atler@pld-linux.org> 67ac098
- up to 1.23.1

* Fri Feb 03 2023 Jan Palus <atler@pld-linux.org> 45bc63c
- qt4 support was dropped in 1.21.0

* Fri Feb 03 2023 Jan Palus <atler@pld-linux.org> c9afd3a
- up to 1.23.0

* Mon Oct 10 2022 Jan Palus <atler@pld-linux.org> 3397a24
- rebuild it attempt to fix "failed to set dynamic section sizes: bad value" on i686

* Tue Jun 28 2022 Jan Palus <atler@pld-linux.org> dc40ee7
- up to 1.22.2

* Tue Jun 21 2022 Jan Palus <atler@pld-linux.org> e1ae1da
- up to 1.22.1

* Mon Jun 06 2022 Jan Palus <atler@pld-linux.org> a517dbf
- fix -gui runtime deps if built against qt5

* Sat Apr 23 2022 Jan Palus <jpalus@fastmail.com> 769e4bf
- fix nosse patch; rel 2

* Sat Apr 23 2022 Jan Palus <atler@pld-linux.org> 4899bbd
- up to 1.22.0

* Sun Apr 25 2021 Jakub Bogusz <qboosh@pld-linux.org> 73ba13c
- updated Source0 URL

* Fri Feb 05 2021 Jan Palus <atler@pld-linux.org> fa0d858
- up to 1.21.1

* Thu Nov 05 2020 Jakub Bogusz <qboosh@pld-linux.org> 27bdd11
- enhanced nosse patch

* Wed Nov 04 2020 Jan Palus <atler@pld-linux.org> edbd7ed
- remove unused patches dropped from spec in 7e80d8d

* Wed Nov 04 2020 Jan Palus <atler@pld-linux.org> 94a1f14
- up to 1.21.0

* Wed Mar 11 2020 Jakub Bogusz <qboosh@pld-linux.org> c41d0d6
- release 2 (libmysofa soname change)

* Fri Jan 24 2020 Jan Palus <atler@pld-linux.org> 14419c3
- up to 1.20.1

* Wed Dec 04 2019 Jakub Bogusz <qboosh@pld-linux.org> b90768b
- ALSOFT_CPUEXT_* are safe (runtime detected); but ALSOFT_ENABLE_SSE2_CODEGEN makes sse2 obligatory
- added nosse patch to allow build on x86 with ALSOFT_ENABLE_SSE2_CODEGEN disabled
- release 2

* Tue Dec 03 2019 Jan Palus <atler@pld-linux.org> 2b67cb4
- BR: libmysofa-devel

* Tue Dec 03 2019 Jan Palus <atler@pld-linux.org> 4d244e7
- use different cmake flags to toggle sse

* Mon Dec 02 2019 Jan Palus <atler@pld-linux.org> 996f154
- up to 1.20.0

